.. RLPy documentation master file, created by
   sphinx-quickstart on Sun Jul 14 22:41:58 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to RLPy's documentation!
================================

RLPy is a framework to conduct sequential decision making experiments. The
current focus of this project lies on value-function-based reinforcement
learning, specifically using linear function approximators.
The project is distributed under the 3-Clause BSD License.

Important Links
===============

- Official source code repository: http://bitbucket.org/rlpy/rlpy
- Github Mirror: http://github.com/rlpy/rlpy
- Documentation and Homepage: http://acl.mit.edu/rlpy
- Download latest version: https://pypi.python.org/pypi/rlpy
- Issue Tracker: http://bitbucket.org/rlpy/rlpy/issues
- Mailing list: rlpy@mit.edu (`***Subscribe here*** <http://mailman.mit.edu/mailman/listinfo/rlpy>`_)

Documentation
=============

.. toctree::
   :maxdepth: 2
    
   big_picture
   install
   tutorial
   make_agent
   make_rep
   make_domain
   make_policy
   unittests
   faq
   api/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
